require 'rack'
require_relative "main"
module Orkester
  class Router

    attr_accessor :routes 


    def initialize
      self.routes = []
      add_route(/\/orkester\/(.*)\/javascripts\/main.js/, :render_javascripts)
      add_route(/\/orkester\/(.*)\/stylesheets\/main.css/, :render_stylesheets)
      add_route(/\/orkester\/(.*)\/info/, :render_index)
    end

    def try(env)
      req = Rack::Request.new(env)
      path = req.path
      self.routes.each do |route|
        match = path.match(route[:regex])
        if match
          match = match.to_a
          args = match.slice 1, match.size
          return self.send route[:method], *args
        else
        end
      end
      nil
    end

    def render_index(package_name)
      path = Orkester.root.join(package_name, "index.html")
      if path.exist?
        html = File.read path
      else
        html = " No index.html  "
      end
      [200, {"Content-Type" => "text/html"}, [html]  ]
    end

    def render_javascripts(package_name)
      renderer = Orkester::Main.new root: Orkester.root
      result = renderer.compile_package package_name

      javascripts = result.javascripts

      [200, {"Content-Type" => "text/javascript"}, javascripts  ]
    end

    def render_stylesheets(package_name)
      renderer = Orkester::Main.new root: Orkester.root
      result = renderer.compile_package package_name

      stylesheets = result.stylesheets

      [200, {"Content-Type" => "text/css"}, stylesheets  ]
    end

    def add_route(route, method)
      self.routes.push({
        regex: route,
        method: method
      })
    end

  end
end